@@ -1,13 +1,13 @@
-# Copyrights 2001-2010 by Mark Overmeer.
+# Copyrights 2001-2012 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 use strict;
 use warnings;
 
 package Mail::Box::Parser::Perl;
 use vars '$VERSION';
-$VERSION = '2.096';
+$VERSION = '2.102';
 
 use base 'Mail::Box::Parser';
 
@@ -110,7 +110,7 @@ sub _is_good_end($)
     return 1 unless defined $line;
 
         substr($line, 0, length $sep) eq $sep
-    && ($sep ne 'From ' || $line =~ m/ (19[789]|20[01])\d\b/ );
+    && ($sep ne 'From ' || $line =~ m/ (?:19[6-9]|20[0-2])[0-9]\b/ );
 }
 
 sub readSeparator()
@@ -162,8 +162,6 @@ sub _read_stripped_lines(;$$)
                 $file->setpos($where);
                 $msgend = $file->tell;
                 last LINE;
-
-                last LINE;
             }
 
             push @$lines, $line;
