@@ -1,13 +1,13 @@
-# Copyrights 2001-2010 by Mark Overmeer.
+# Copyrights 2001-2012 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 use strict;
 use warnings;
 
 package Mail::Message::Body;
 use vars '$VERSION';
-$VERSION = '2.096';
+$VERSION = '2.102';
 
 use base 'Mail::Reporter';
 
@@ -17,7 +17,7 @@ use Mail::Message::Body::File;
 
 use Carp;
 use Scalar::Util     qw/weaken refaddr/;
-use File::Basename   'basename';
+use File::Basename   qw/basename/;
 
 use MIME::Types;
 my $mime_types = MIME::Types->new;
